import "../../../client/dist/internal/logger/index.js";
import { waitForResource } from "../../../client/dist/internal/async/interval-retrier.js";
import { API as API$1 } from "../../../client/dist/scw/api.js";
import { validatePathParam, urlParams } from "../../../client/dist/helpers/marshalling.js";
import "../../../client/dist/vendor/base64/index.js";
import { enrichForPagination } from "../../../client/dist/scw/fetch/resource-paginator.js";
import { FILE_SYSTEM_TRANSIENT_STATUSES } from "./content.gen.js";
import { unmarshalFileSystem, unmarshalListFileSystemsResponse, unmarshalListAttachmentsResponse, marshalCreateFileSystemRequest, marshalUpdateFileSystemRequest } from "./marshalling.gen.js";
const jsonContentHeaders = {
  "Content-Type": "application/json; charset=utf-8"
};
class API extends API$1 {
  /** Lists the available regions of the API. */
  static LOCALITIES = ["fr-par"];
  /**
   * Get filesystem details. Retrieve all properties and current status of a specific filesystem identified by its ID.
   *
   * @param request - The request {@link GetFileSystemRequest}
   * @returns A Promise of FileSystem
   */
  getFileSystem = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/file/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/filesystems/${validatePathParam("filesystemId", request.filesystemId)}`
    },
    unmarshalFileSystem
  );
  /**
   * Waits for {@link FileSystem} to be in a final state.
   *
   * @param request - The request {@link GetFileSystemRequest}
   * @param options - The waiting options
   * @returns A Promise of FileSystem
   */
  waitForFileSystem = (request, options) => waitForResource(
    options?.stop ?? ((res) => Promise.resolve(
      !FILE_SYSTEM_TRANSIENT_STATUSES.includes(res.status)
    )),
    this.getFileSystem,
    request,
    options
  );
  pageOfListFileSystems = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/file/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/filesystems`,
      urlParams: urlParams(
        ["name", request.name],
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId],
        ["tags", request.tags]
      )
    },
    unmarshalListFileSystemsResponse
  );
  /**
     * List all filesystems. Retrieve all filesystems in the specified region. Results are ordered by creation date in ascending order by default.
  Use the order_by parameter to modify the sorting behavior.
     *
     * @param request - The request {@link ListFileSystemsRequest}
     * @returns A Promise of ListFileSystemsResponse
     */
  listFileSystems = (request = {}) => enrichForPagination("filesystems", this.pageOfListFileSystems, request);
  pageOfListAttachments = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/file/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/attachments`,
      urlParams: urlParams(
        ["filesystem_id", request.filesystemId],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["resource_id", request.resourceId],
        ["resource_type", request.resourceType]
      )
    },
    unmarshalListAttachmentsResponse
  );
  /**
     * List filesystems attachments. List all existing attachments in a specified region.
  By default, the attachments listed are ordered by creation date in ascending order.
  This can be modified using the `order_by` field.
     *
     * @param request - The request {@link ListAttachmentsRequest}
     * @returns A Promise of ListAttachmentsResponse
     */
  listAttachments = (request = {}) => enrichForPagination("attachments", this.pageOfListAttachments, request);
  /**
   * Create a new filesystem. To create a new filesystem, you need to provide a name, a size, and a project ID.
   *
   * @param request - The request {@link CreateFileSystemRequest}
   * @returns A Promise of FileSystem
   */
  createFileSystem = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalCreateFileSystemRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/file/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/filesystems`
    },
    unmarshalFileSystem
  );
  /**
   * Delete a detached filesystem. You must specify the `filesystem_id` of the filesystem you want to delete.
   *
   * @param request - The request {@link DeleteFileSystemRequest}
   */
  deleteFileSystem = (request) => this.client.fetch({
    method: "DELETE",
    path: `/file/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/filesystems/${validatePathParam("filesystemId", request.filesystemId)}`
  });
  /**
     * Update filesystem properties. Update the technical details of a filesystem, such as its name, tags or its new size.
  You can only resize a filesystem to a larger size.
     *
     * @param request - The request {@link UpdateFileSystemRequest}
     * @returns A Promise of FileSystem
     */
  updateFileSystem = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalUpdateFileSystemRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/file/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/filesystems/${validatePathParam("filesystemId", request.filesystemId)}`
    },
    unmarshalFileSystem
  );
}
export {
  API
};
